#include "mapdialog.h"
#include "ui_mapdialog.h"

MapDialog::MapDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Dialog)
{
    ui->setupUi(this);
    setWindowTitle(tr("Choose Location[*]"));

}

int MapDialog::exec() {
    view->setParent(ui->widget);
    if (view->source().isEmpty()) {
        view->setSource(QUrl("qrc:///qml/googlemaps.qml"));
        view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    }

    QDeclarativeItem *item = qobject_cast<QDeclarativeItem *>(view->rootObject());
    item->setProperty("defaultLatitude", latitude);
    item->setProperty("defaultLongitude", longitude);
    qDebug() << item->property("defaultLatitude");
    qDebug() << item->property("defaultLongitude");
    int result = QDialog::exec();

    latitude = item->property("latitude").toDouble();
    longitude = item->property("longitude").toDouble();
    view->setParent(parentWidget());
    return result;
}

MapDialog::~MapDialog()
{
    delete ui;
}
